pub fn init_read_only(
config: Config,
network: &Network,
) -> Result<(ReadStateService, ZebraDb, Sender<NonFinalizedState>), StateInitError>Expand description
Initialize a read state service from the provided Config.
Returns a read-only state service,
Each network has its own separate on-disk database.
To share access to the state, clone the returned ReadStateService.