pub struct ChainTipBlock {
pub hash: Hash,
pub height: Height,
pub time: DateTime<Utc>,
pub transactions: Vec<Arc<Transaction>>,
pub transaction_hashes: Arc<[Hash]>,
pub previous_block_hash: Hash,
}Expand description
A chain tip block, with precalculated block data.
Used to efficiently update ChainTipSender, LatestChainTip,
and ChainTipChange.
Fields
hash: HashThe hash of the best chain tip block.
height: HeightThe height of the best chain tip block.
time: DateTime<Utc>The network block time of the best chain tip block.
transactions: Vec<Arc<Transaction>>The block transactions.
transaction_hashes: Arc<[Hash]>The mined transaction IDs of the transactions in block,
in the same order as block.transactions.
previous_block_hash: HashThe hash of the previous block in the best chain. This block is immediately behind the best chain tip.
Note
If the best chain fork has changed, or some blocks have been skipped,
this hash will be different to the last returned ChainTipBlock.hash.