TypedColumnFamily

Struct TypedColumnFamily 

pub struct TypedColumnFamily<'cf, Key, Value>
where Key: IntoDisk + FromDisk + Debug, Value: IntoDisk + FromDisk,
{ db: DiskDb, cf: ColumnFamilyRef<'cf>, _cf_name: String, _marker: PhantomData<(Key, Value)>, }
A type-safe read-only column family reference.

Use this struct instead of raw ReadDisk access, because it is type-safe. So you only have to define the types once, and you can’t accidentally use different types for reading and writing. (Which is a source of subtle database bugs.)

Fields

db: DiskDb

The database.

cf: ColumnFamilyRef<'cf>

The column family reference in the database.

_cf_name: String

The column family name, only used for debugging and equality checking.

_marker: PhantomData<(Key, Value)>

A marker type used to bind the key and value types to the struct.

Implementations

Source

impl<'cf, Key, Value> TypedColumnFamily<'cf, Key, Value>
where Key: IntoDisk + FromDisk + Debug, Value: IntoDisk + FromDisk,

pub fn new(db: &'cf DiskDb, cf_name: &str) -> Option<Self>

Returns a new typed column family, if it exists in the database.

pub fn new_batch_for_writing( self, ) -> WriteTypedBatch<'cf, Key, Value, DiskWriteBatch>

Returns a typed writer for this column family for a new batch.

These methods are the only way to get a WriteTypedBatch, which ensures that the read and write types are consistent.

pub fn take_batch_for_writing( self, batch: DiskWriteBatch, ) -> WriteTypedBatch<'cf, Key, Value, DiskWriteBatch>

Wraps an existing write batch, and returns a typed writer for this column family.

These methods are the only way to get a WriteTypedBatch, which ensures that the read and write types are consistent.

pub fn with_batch_for_writing( self, batch: &mut DiskWriteBatch, ) -> WriteTypedBatch<'cf, Key, Value, &mut DiskWriteBatch>

Wraps an existing write batch reference, and returns a typed writer for this column family.

These methods are the only way to get a WriteTypedBatch, which ensures that the read and write types are consistent.

pub fn zs_is_empty(&self) -> bool

Returns true if this rocksdb column family does not contain any entries.

pub fn zs_get(&self, key: &Key) -> Option<Value>

Returns the value for key in this rocksdb column family, if present.

pub fn zs_contains(&self, key: &Key) -> bool

Check if this rocksdb column family contains the serialized form of key.

pub fn zs_first_key_value(&self) -> Option<(Key, Value)>

Returns the lowest key in this column family, and the corresponding value.

Returns None if this column family is empty.

pub fn zs_last_key_value(&self) -> Option<(Key, Value)>

Returns the highest key in this column family, and the corresponding value.

Returns None if this column family is empty.

pub fn zs_next_key_value_from(&self, lower_bound: &Key) -> Option<(Key, Value)>

Returns the first key greater than or equal to lower_bound in this column family, and the corresponding value.

Returns None if there are no keys greater than or equal to lower_bound.

pub fn zs_next_key_value_strictly_after( &self, lower_bound: &Key, ) -> Option<(Key, Value)>

Returns the first key strictly greater than lower_bound in this column family, and the corresponding value.

Returns None if there are no keys greater than lower_bound.

pub fn zs_prev_key_value_back_from( &self, upper_bound: &Key, ) -> Option<(Key, Value)>

Returns the first key less than or equal to upper_bound in this column family, and the corresponding value.

Returns None if there are no keys less than or equal to upper_bound.

pub fn zs_prev_key_value_strictly_before( &self, upper_bound: &Key, ) -> Option<(Key, Value)>

Returns the first key strictly less than upper_bound in this column family, and the corresponding value.

Returns None if there are no keys less than upper_bound.

pub fn zs_forward_range_iter<Range>( &self, range: Range, ) -> impl Iterator<Item = (Key, Value)> + '_
where Range: RangeBounds<Key>,

Returns a forward iterator over the items in this column family in range.

Holding this iterator open might delay block commit transactions.

pub fn zs_reverse_range_iter<Range>( &self, range: Range, ) -> impl Iterator<Item = (Key, Value)> + '_
where Range: RangeBounds<Key>,

Returns a reverse iterator over the items in this column family in range.

Holding this iterator open might delay block commit transactions.

Source

impl<Key, Value> TypedColumnFamily<'_, Key, Value>
where Key: IntoDisk + FromDisk + Debug + Ord, Value: IntoDisk + FromDisk,

pub fn zs_items_in_range_ordered<Range>( &self, range: Range, ) -> BTreeMap<Key, Value>
where Range: RangeBounds<Key>,

Returns the keys and values in this column family in range, in an ordered BTreeMap.

Holding this iterator open might delay block commit transactions.

Source

impl<Key, Value> TypedColumnFamily<'_, Key, Value>
where Key: IntoDisk + FromDisk + Debug + Hash + Eq, Value: IntoDisk + FromDisk,

pub fn zs_items_in_range_unordered<Range>( &self, range: Range, ) -> HashMap<Key, Value>
where Range: RangeBounds<Key>,

Returns the keys and values in this column family in range, in an unordered HashMap.

Holding this iterator open might delay block commit transactions.